/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.ozone.container.common.report;

import org.apache.hadoop.hdds.scm.container.common.helpers.StorageContainerException;

/**
 * IncrementalReportSender is an interface to send ICRs.
 * @param <T>
 */
public interface IncrementalReportSender<T> {
  /**
   * Send ICR immediately (triggers heartbeat).
   */
  void send(T t) throws StorageContainerException;
  
  /**
   * Send deferred ICR to next scheduled heartbeat (no immediate trigger).
   */
  default void sendDeferred(T t) throws StorageContainerException {
    send(t);
  }
}
